package com.xyzc.start.controller;

import com.xyzc.common.core.utils.Result;
import com.xyzc.start.domain.bo.CreateOrderBo;
import com.xyzc.start.domain.vo.*;
import com.xyzc.start.service.ISchemeService;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 套餐购买
 *
 * @author 杨兴卓
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/scheme")
public class SchemeController {

    private final ISchemeService schemeService;

//    @DubboReference(mock = "true")
//    private final RemotePayService remotePayService;

    /**
     * 会员卡生效套餐信息
     */
    @GetMapping("/currentMember")
    public Result<SchemeVo> current() {
        SchemeVo scheme = schemeService.getCurrentMember();

        return Result.ok(scheme);
    }

    /**
     * 会员卡订单展示
     */
    @GetMapping("/memberOrder")
    public Result<BaseUserOrderVo> queryOrder() {
//        BaseUserOrderVo userOrder = schemeService.queryOrder();

        return Result.ok();
    }

    /**
     * 购买物品订单生成（单个卡片或燃料）
     */
    @PostMapping("/createOrder")
    public Result<BaseUserOrderVo> createOrder(@RequestBody @Valid CreateOrderBo bo){
        BaseUserOrderVo userOrder = schemeService.createOrder(bo);

        return Result.ok(userOrder);
    }

    /**
     * 点击支付
     */
    @PostMapping("/orderPay")
    public Result<String> orderPay(@RequestBody @Valid CreateOrderBo bo){

        return Result.ok();
    }



    /**
     * 燃料包生效套餐信息
     */
    @GetMapping("/currentFuel")
    public Result<SchemeVo> currentFuel() {
        SchemeVo scheme = schemeService.getCurrentFuel();

        return Result.ok(scheme);
    }


    /**
     * 燃料规则
     *
     * @param modelId 模型id
     */
    @GetMapping("/fuelLaw")
    public Result<List<AiModelLawVo>> queryfuelLawList(Long modelId) {
        List<AiModelLawVo> fuelPackageList = schemeService.queryModelLawList(modelId);

        return Result.ok(fuelPackageList);
    }

}
