package com.xyzc.start.service.impl;

import cn.hutool.core.date.DateUtil;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xyzc.common.core.exception.ErrorCode;
import com.xyzc.common.core.exception.ServerException;
import com.xyzc.common.web.security.user.SecurityUser;
import com.xyzc.start.domain.*;
import com.xyzc.start.mapper.*;
//import com.xyzc.start.mapper.NpTextMapper;
import com.xyzc.start.service.INpCommitService;
import com.xyzc.start.service.INpQueryService;
import com.xyzc.start.utils.SnowflakeIdWorker;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.logging.log4j.util.Strings;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.core.io.FileSystemResource;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.client.RestTemplate;
import org.springframework.web.multipart.MultipartFile;

import java.io.File;
import java.security.NoSuchAlgorithmException;
import java.util.*;

import static com.xyzc.start.utils.EncryptUtil.getMD5Byparam;

import java.util.function.Supplier;
@Service
@RequiredArgsConstructor
@Slf4j
public class NpCommitServiceImpl implements INpCommitService {
    // 基本URL请求
    String baseUrl = "https://meta.guiji.ai";

    String appKey = "IyeVRCSyBokinWIcrTjXVeOq";
    String appSecret = "PFp3PZeEJIIRTtHqyG6Hhp1pyiS0ETjsb30XZVVhwR2n4WYQF4aI9A7EzUCrPsML";

    String callBackHost = "https://62e6ffcb.r11.cpolar.top";

    RestTemplate restTemplate = new RestTemplate();

//    private final INpQueryService npQueryService;

    private final NpCommitTrainMapper npCommitTrainMapper;

    private final NpMaterialMapper npMaterialMapper;

    private final NpMusicMapper npMusicMapper;

//    private final NpTextMapper npTextMapper;

    private INpQueryService queryService;

    private final NpVideoDraftMapper npVideoDraftMapper;

    private final NpTemplateDraftMapper npTemplateDraftMapper;

    @Autowired
    public void NpCommitServiceImpl(@Lazy INpQueryService queryService) {
        this.queryService = queryService;
    }

    /**
     * 获取token
     * @throws NoSuchAlgorithmException
     */
    @Override
    public String getToken() throws NoSuchAlgorithmException {
        long timeStamp = System.currentTimeMillis();
        String encrypted = getMD5Byparam(appKey + timeStamp + appSecret);

        log.info("加密后的结果：" + encrypted);

        String url = "https://meta.guiji.ai/openapi/oauth/token?grant_type=sign&timestamp=" + timeStamp + "&sign=" + encrypted + "&appId=" + appKey;

        String forObject = restTemplate.getForObject(url, String.class);
        log.info("获取到的token：" + forObject);
        JSONObject jsonObject = JSONObject.parseObject(forObject);
        String code = jsonObject.getString("code");
        String accessToken = "";
        if ("0".equals(code)) {
            JSONObject dataJSON = jsonObject.getJSONObject("data");
            accessToken = dataJSON.getString("access_token");
            String expiresIn = dataJSON.getString("expires_in");
            String scope = dataJSON.getString("scope");
            JSONObject userInfoJSON = dataJSON.getJSONObject("userInfo");
            Integer corpId = userInfoJSON.getInteger("corpId");
            Integer id = userInfoJSON.getInteger("id");
            Integer userId = userInfoJSON.getInteger("userId");
            // 获取到的token：{"code":"0","data":{"access_token":"796916ae-6fb1-4d51-8e80-6543081366c5","userInfo":{"corpId":1251421,"id":93,"userId":355352},"scope":"all","expires_in":7182},"success":true}
            // 获取到的token：{"code":"0","data":{"access_token":"7ac45bf8-c3bb-4d19-a187-c1ecbf9b3ed0","userInfo":{"corpId":1251421,"id":93,"userId":355352},"scope":"all","expires_in":7199},"success":true}
        }else{
//            errorCode(code);
        }
        return accessToken;
    }



    /**
     * 提交训练视频
     */
    @Override
    public void commitTrainVideo(NpCommitTrain npCommitTrain) {
        // 判断 视频是否上传
        if (Strings.isBlank(npCommitTrain.getVideoUrl())) {
            log.error(ErrorCode.NUMERSON_NO_VIDEO.toString());
            throw new ServerException(ErrorCode.NUMERSON_NO_VIDEO);
        }
        // 判断 名称是否定义
        if (Strings.isBlank(npCommitTrain.getName())) {
            log.error(ErrorCode.NUMERSON_NO_VIDEO_NAME.toString());
            throw new ServerException(ErrorCode.NUMERSON_NO_VIDEO_NAME);
        }
        // 判断 是否绿幕是否定义
        if (null == npCommitTrain.getGreenScreen()) {
            log.error(ErrorCode.NUMERSON_NO_GREEN.toString());
            throw new ServerException(ErrorCode.NUMERSON_NO_GREEN);
        }

        String accessToken = "";
        try {
            accessToken = getToken();
        } catch (NoSuchAlgorithmException e) {
            throw new RuntimeException(e);
        }

        String url = baseUrl + "/openapi/video/v2/create/training?access_token=" + accessToken;
        MultiValueMap<String, Object> map = new LinkedMultiValueMap<>();

        HttpHeaders headers = new HttpHeaders();
        headers.add("Content-Type","application/json;charset=UTF-8");

        JSONObject jsonParam = new JSONObject();

//        jsonParam.put("id", ""); // 训练任务ID，id为空表示提交新训练，id不为空表示更新训练
        jsonParam.put("name", npCommitTrain.getName()); // 数字人名称
        jsonParam.put("level", "359"); // 定制套餐级别： 空或2.形象克隆-高阶版 358.形象克隆-S级-超清 359.形象克隆-E级 360.形象克隆-S级
        jsonParam.put("videoUrl", npCommitTrain.getVideoUrl()); // 训练视频url，需公网可访问
//        jsonParam.put("callbackUrl", "http://121.15.198.153:18068/numberPerson/NumberPersonCommitNotify"); // 训练状态回调地址
        jsonParam.put("callbackUrl", callBackHost + "/numPerson/commitTrainVedioNotify"); // 训练状态回调地址
        jsonParam.put("greenScreen", npCommitTrain.getGreenScreen()); // 是否是绿幕: 0.否 1.是

        HttpEntity<JSONObject> param = new HttpEntity(jsonParam, headers);
        log.info("url:"+url);
        log.info("请求参数:"+jsonParam);
        String returnData = restTemplate.postForObject(url, param, String.class);
        JSONObject jsonObject = JSONObject.parseObject(returnData);
        log.info("返回参数：" + jsonObject);
        if ("0".equals(jsonObject.getString("code"))) {
            Integer trainingId = jsonObject.getJSONObject("data").getInteger("trainingId");
            npCommitTrain.setModelId(trainingId);
            npCommitTrainMapper.insert(npCommitTrain);
        }
    }


    /**
     * 3.21 素材上传接口
     */
    @Override
    public void uploadMaterial(MultipartFile file, String rootId) {
        if (null == file) {
            log.error("请上传文件");
            throw new ServerException(ErrorCode.NUMERSON_NO_FILE);
        }
        if (Strings.isBlank(rootId) || !Arrays.asList("0", "1", "4").contains(rootId)) {
            log.error("请指定类型");
            throw new ServerException(ErrorCode.NUMERSON_NO_TYPE);
        }

        int lastIndexOf = file.getOriginalFilename().lastIndexOf(".");
        String suffixName = file.getOriginalFilename().substring(lastIndexOf);
        if ("0".equals(rootId) && !Arrays.asList(".png", ".jpg", ".gif").contains(suffixName)) {
            log.error("请上传png/jpg/gif文件类型");
            throw new ServerException(ErrorCode.NUMERSON_NO_FILE);
        }

        String accessToken = "";
        try {
            accessToken = getToken();
        } catch (NoSuchAlgorithmException e) {
            throw new RuntimeException(e);
        }

        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(MediaType.MULTIPART_FORM_DATA);
        // 创建包含文件的请求体
        MultiValueMap<String, Object> body = new LinkedMultiValueMap<>();
        body.add("rootId", rootId);

//        MultipartFile multipartFile = null; // 这里需要实际的 MultipartFile 对象
        try {
            File f = File.createTempFile("temp", suffixName);
            file.transferTo(f);
            FileSystemResource fileSystemResource = new FileSystemResource(f.getAbsolutePath());
            body.add("file", fileSystemResource);
        } catch (Exception e) {
            log.error("上传文件失败");
            throw new ServerException(ErrorCode.NUMERSON_FAIL_FILE);
        }
//        JSONObject jsonObject2 = queryService.queryOpenAPIMaterial(Integer.valueOf(rootId), 1, 50);

        String url = baseUrl + "/openapi/material/upload?access_token=" + accessToken;

        HttpEntity<MultiValueMap<String, Object>> requestEntity = new HttpEntity<>(body, headers);
        ResponseEntity<JSONObject> response = restTemplate.postForEntity(url, requestEntity, JSONObject.class);
        JSONObject returnData = response.getBody();
        if("0".equals(returnData.getString("code"))){
            Integer dataId = returnData.getInteger("data");
            Long baseUserId = SecurityUser.getUserId();
            NpMaterial npMaterial = new NpMaterial();
            // 根据
            JSONObject jsonObject = queryService.queryOpenAPIMaterial(Integer.valueOf(rootId), 1, 50);
            if("0".equals(jsonObject.getString("code"))){
                LinkedHashMap data = (LinkedHashMap) jsonObject.get("data");
                ArrayList records = (ArrayList)data.get("records");
                for (int i = 0; i < records.size(); i++) {
                    LinkedHashMap record = (LinkedHashMap) records.get(i);
                    Integer materialId = (Integer) record.get("id");
//                    int delFlag = (Integer) record.get("delFlag");
                    if(materialId.equals( dataId)){
                        if(null != record.get("bgFormat")){
                            String bgFormat = record.get("bgFormat").toString();
                            npMaterial.setBgFormat(bgFormat);
                        }
                        if(null != record.get("backgroundType")){
                            Integer backgroundType = (Integer) record.get("backgroundType");
                            npMaterial.setBackgroundType(backgroundType);
                        }
                        if(null != record.get("coverUrl")){
                            String coverUrl = record.get("coverUrl").toString();
                            npMaterial.setCoverUrl(coverUrl);
                        }
//                        if(null != record.get("userId")){
//                            String materialuserId = record.get("userId").toString();
////                            npMaterial.setid
//                        }
                        if (null != record.get("backgroundName")) {
                            String backgroundName = record.get("backgroundName").toString();
                            npMaterial.setBackgroundName(backgroundName);
                        }
                        if (null != record.get("zipCoverUrl")) {
                            String zipCoverUrl = record.get("zipCoverUrl").toString();
                            npMaterial.setZipCoverUrl(zipCoverUrl);
                        }
                        if (null != record.get("backgroundCode")) {
                            String backgroundCode = record.get("backgroundCode").toString();
                            npMaterial.setBackgroundCode(backgroundCode);
                        }
                        if (null != record.get("userId")) {
                            String userId = record.get("userId").toString();
                            npMaterial.setUserId(Integer.parseInt(userId));
                        }
                        if (null != record.get("createTime")) {
                            Long createTime = Long.valueOf(record.get("createTime").toString());
                            npMaterial.setCreateTime(new Date(createTime));
                        }
                        npMaterial.setMaterialId(dataId);
                        npMaterial.setMaterialType(Integer.parseInt(rootId));
                        npMaterial.setBaseUserId(baseUserId);

                        npMaterialMapper.insert(npMaterial);
                        break;
                    }
                }
            }else{
                throw new ServerException(ErrorCode.NUMERSON_FAIL_FILE);
            }
        }
        System.out.println("returnData:+" + response);
    }

    //  可删除
    public void queryMaterial(String rootId, String page, String size) {
        if (null == rootId) {
            log.error("请输入素材类型");
            throw new ServerException(ErrorCode.NUMERSON_NO_TYPE);
        }
        if (Strings.isBlank(page)) {
            page = "1";
        }
        if (Strings.isBlank(size)) {
            size = "10";
        }



//        String accessToken = "";
//        try {
//            accessToken = getToken();
//        } catch (NoSuchAlgorithmException e) {
//            throw new RuntimeException(e);
//        }
//        String url = baseUrl + "/openapi/material/search?access_token=" + accessToken;
//
//        JSONObject jsonParam = new JSONObject();
//        jsonParam.put("rootId", rootId); // 素材类型 ，0：背景（图片或者视频），1：图片素材，4：视频素材
//        jsonParam.put("page", "1");
//        jsonParam.put("size", "100");
//        jsonParam.put("asc", "true");
////        jsonParam.put("myself", "true"); // 是否是自己上传的
//        HttpHeaders headers = new HttpHeaders();
//        headers.add("Content-Type","application/json;charset=UTF-8");
//        //构造实体对象
//        HttpEntity<JSONObject> param = new HttpEntity<>(jsonParam, headers);
//
//        JSONObject returnDataJSON = restTemplate.postForObject(url, param, JSONObject.class);
//        System.out.println(returnDataJSON);
//        if ("0".equals(returnDataJSON.getString("code"))) {
//            LinkedHashMap data = (LinkedHashMap) returnDataJSON.get("data");
//            ArrayList records = (ArrayList)data.get("records");
//            List<NpMaterial> materialList = npMaterialMapper.selectList(new QueryWrapper<NpMaterial>().eq("material_type", rootId).select("material_id"));
//            ArrayList<Integer> materialIdList = materialList.stream().map(m -> m.getMaterialId()).collect(Collectors.toCollection(ArrayList::new));
//            for (int i = 0; i < records.size(); i++) {
//                LinkedHashMap record = (LinkedHashMap) records.get(i);
//                if(!materialIdList.contains(record.get("id"))){
//                    NpMaterial npMaterial = new NpMaterial();
//                    if("1".equals(rootId)) {
//                        npMaterial.setMaterialId(Integer.parseInt(record.get("id").toString()));
//                        npMaterial.setMaterialType(Integer.parseInt(rootId));
//                        npMaterial.setDescription(record.get("description").toString());
//                        npMaterial.setBackgroundName(record.get("name").toString());
//                        npMaterial.setUrl(record.get("url").toString());
//                        npMaterial.setThumbnailUrl(record.get("thumbnailUrl").toString());
//                        npMaterial.setOwnerCorpId(Integer.parseInt(record.get("ownerCorpId").toString()));
//                    } else if ("0".equals(rootId)) {
//
//                    }else if("4".equals(rootId)){
//
//                    }
//                    npMaterialMapper.insert(npMaterial);
//                }
//            }
//        }
    }

    @Override
    public void uploadMusic(NpMusic npMusic) {
        if (Strings.isBlank(npMusic.getMusicUrl())) {
            log.error("请输入地址");
            throw new ServerException(ErrorCode.NUMERSON_NO_URL);
        }
        if (Strings.isBlank(npMusic.getMusicUrl())) {
            log.error("请输入名称");
            throw new ServerException(ErrorCode.NUMERSON_NO_NAME);
        }

        npMusic.setBaseUserId(SecurityUser.getUserId());
        npMusicMapper.insert(npMusic);

    }

    @Override
    public void  uploadCommonTemplate(NpFormwork npFormwork) {
        if (Strings.isBlank(npFormwork.getNodes())) {
            log.error("请输入模板");
            throw new ServerException(ErrorCode.NUMERSON_NO_MODEL);
        }
        if (Strings.isBlank(npFormwork.getName())) {
            log.error("请输入名称");
            throw new ServerException(ErrorCode.NUMERSON_NO_NAME);
        }
        if (null == npFormwork.getType() ) {
            log.error("请输入类型");
            throw new ServerException(ErrorCode.NUMERSON_NO_TYPE);
        }
        if (null == npFormwork.getFormworkType() ) {
            log.error("请输入类型");
            throw new ServerException(ErrorCode.NUMERSON_NO_TYPE);
        }

        int i = npTemplateDraftMapper.insertNpFormwork(npFormwork);
        if(i == 0){
            log.error("保存失败");
        }

    }

    @Override
    public void udateDraftName(NpTemplateDraft templateDraft) {
//        npTemplateDraftMapper.update(new QueryWrapper<NpTemplateDraft>().eq("id",templateDraft.getId()).set("draft_name",templateDraft.getDraftName()));
        templateDraft.setBaseUserId(SecurityUser.getUserId());
        npTemplateDraftMapper.insertOrUpdate(templateDraft);
    }

    @Override
    public void deleteDraftById(NpTemplateDraft templateDraft) {
//        npTemplateDraftMapper.update(new QueryWrapper<NpTemplateDraft>().eq("id",templateDraft.getId()).set("draft_name",templateDraft.getDraftName()));
        Long id = templateDraft.getId();
        if (null == id) {
            log.error("请输入id");
            throw new ServerException(ErrorCode.NUMERSON_NO_ID);
        }
        npTemplateDraftMapper.deleteById(id);
    }


//    Long baseUserId = SecurityUser.getUserId();
//    List<NpVideoDraft> videoDraftList = npVideoDraftMapper.selectList(new QueryWrapper<NpVideoDraft>().eq("base_user_id", baseUserId).eq("type", "1"));
//
//    String nodeJson = "";
//        if (Strings.isBlank(templateId) && videoDraftList.isEmpty()) {
//        NpVideoDraft videoDraft = npVideoDraftMapper.selectOne(new QueryWrapper<NpVideoDraft>().eq("id", "1"));
//        nodeJson = videoDraft.getNodesJson();
//
//        SnowflakeIdWorker snowflakeIdWorker = new SnowflakeIdWorker(1, 1);
//        long l = snowflakeIdWorker.nextId();
//        videoDraft.setId(l);
//        videoDraft.setNodesJson(nodeJson);
//    }
//
//        return videoDraftList;

//    @Override
//    public void uploadText(NpText npText) {
//
//    }

//    @Override
//    public void uploadText(NpText npText) {
//        if (Strings.isBlank(npText.getText())) {
//            log.error("请输入文本");
//            throw new ServerException(ErrorCode.NUMERSON_NO_TEXT);
//        }
//        if (Strings.isBlank(npText.getImgUrl())) {
//            log.error("请输入地址");
//            throw new ServerException(ErrorCode.NUMERSON_NO_URL);
//        }
//        if (Strings.isBlank(npText.getImgUrl())) {
//            log.error("请输入地址");
//            throw new ServerException(ErrorCode.NUMERSON_NO_TYPE);
//        }
//
//        npText.setBaseUserId(SecurityUser.getUserId());
//        npTextMapper.insert(npText);
//    }

    /**
     * 3.6 创建视频合成任务-音频合成
     */
    public void createVideoTask(){

        String accessToken = "";
        try {
            accessToken = getToken();
        } catch (NoSuchAlgorithmException e) {
            throw new RuntimeException(e);
        }

        String url = baseUrl + "/openapi/video/v2/create?access_token=" + accessToken;
        HttpHeaders headers = new HttpHeaders();
        headers.add("Content-Type","application/json;charset=UTF-8");

        JSONObject jsonParam = new JSONObject();
        jsonParam.put("audioUrl", "https://tts.guiji.ai/source/voiceclone/501556zhaozong_sound.wav"); // 音频地址，需公网可访问
        jsonParam.put("sceneId", "195849044"); // 场景ID，从模特列表接口获取
        jsonParam.put("backgroundUrl", "https://cdn.guiji.ai/video-server/jpg/1823694251370942465.jpg"); // 自定义背景，需公网可访问
        jsonParam.put("videoName", "xulonglin");      // 合成作品名称
        jsonParam.put("bitRate", "16M");        // 视频码率 可选值：1M、1.5M、3M、3.5M、5M、7M、8M、10M、12M、16M
//        jsonParam.put("width", "100");          // 横向分辨率（默认’1080’）
//        jsonParam.put("height", "100");         // 纵向分辨率（默认’1920’）
//        jsonParam.put("mask", "1");
        jsonParam.put("fps", "30");                 // fps 可选值："15"、 "20"、 "25"、 "30"
        jsonParam.put("callbackUrl", "http://121.15.198.153:8068/common/api/NumberPersonCommitNotify");
//        jsonParam.put("matting", "1");
//        jsonParam.put("pixFmt", "yuv444p");
//        jsonParam.put("videoFormat", "100");
        JSONObject style = new JSONObject();
        style.put("x", "1");
        style.put("y", "1");
        style.put("width", "500");
        style.put("height", "500");
        style.put("indexLayer", "100");
        jsonParam.put("style", style);


        JSONArray nodes = new JSONArray();

        JSONObject nodeStyleJSON = new JSONObject();
        nodeStyleJSON.put("type", "2");
        nodeStyleJSON.put("url", "https://cdn.guiji.ai/video-server/jpg/1816079643308826626.jpg");
        nodeStyleJSON.put("indexLayer", "50");
        nodeStyleJSON.put("rotation", "50");
        JSONObject json3 = new JSONObject();
        json3.put("x", "3");
        json3.put("y", "3");
        json3.put("width", "300");
        json3.put("height", "400");
        nodeStyleJSON.put("style", json3);
        nodes.add(nodeStyleJSON);

        JSONObject nodeJSON2 = new JSONObject();
        nodeJSON2.put("type", "1");
        nodeJSON2.put("url", "http://47.121.123.230:9000/xy-dev/comfyui/video/zhanghongrun.mp4");
        nodeJSON2.put("rotation", "101");
        JSONObject json4 = new JSONObject();
        json4.put("x", "4");
        json4.put("y", "4");
        json4.put("width", "50");
        json4.put("height", "50");
        nodeJSON2.put("style", json4);
        nodes.add(nodeJSON2);
        jsonParam.put("nodes", nodes);

        //构造实体对象
        HttpEntity<JSONObject> param = new HttpEntity<>(jsonParam, headers);
        log.info("发送参数jsonParam:" + jsonParam);
        JSONObject returnDataJSON = restTemplate.postForObject(url, param, JSONObject.class);

        log.info("3.6 创建视频合成任务-音频合成"+returnDataJSON.toJSONString());
        if ("0".equals(returnDataJSON.getString("code"))) {
            JSONObject dataJSON = returnDataJSON.getJSONObject("data");
            System.out.println(dataJSON);
            ArrayList records = dataJSON.getObject("records", ArrayList.class);
            for (int i = 0; i < records.size(); i++) {
                LinkedHashMap map = (LinkedHashMap)records.get(i);
                Object id = map.get("id");
                Object robotName = map.get("robotName");
                Object robotDesc = map.get("robotDesc");
                Object coverUrl = map.get("coverUrl");

            }
        }
    }
    /**
     * 3.7 创建合成视频任务-文本合成
     */
    public void createVideoTaskText(){
        String accessToken = "";
        try {
            accessToken = getToken();
        } catch (NoSuchAlgorithmException e) {
            throw new RuntimeException(e);
        }
        String url = baseUrl + "/openapi/video/v2/create/tss?access_token=" + accessToken;
        HttpHeaders headers = new HttpHeaders();
        headers.add("Content-Type","application/json;charset=UTF-8");

        JSONObject jsonParam = new JSONObject();
        jsonParam.put("text", "你好，我是小智"); // 合成文本
        jsonParam.put("speakerId", "942"); // 合成文本
        jsonParam.put("backgroundUrl", "https://cdn.guiji.ai/video-server/jpg/1823694251370942465.jpg"); // 自定义背景，需公网可访问
        jsonParam.put("videoName", "me_is_xiaozhi"); // 合成文本
//        jsonParam.put("audioUrl", "https://tts.guiji.ai/source/voiceclone/501556zhaozong_sound.wav"); // 音频地址，需公网可访问
        jsonParam.put("sceneId", "195849044"); // 场景ID，从模特列表接口获取
        jsonParam.put("bitRate", "16M");        // 视频码率 可选值：1M、1.5M、3M、3.5M、5M、7M、8M、10M、12M、16M
//        jsonParam.put("width", "100");          // 横向分辨率（默认’1080’）
//        jsonParam.put("height", "100");         // 纵向分辨率（默认’1920’）
//        jsonParam.put("mask", "1");
        jsonParam.put("fps", "30");                 // fps 可选值："15"、 "20"、 "25"、 "30"
        jsonParam.put("callbackUrl", "http://121.15.198.153:8068/common/api/NumberPersonCommitNotify");
        jsonParam.put("speechRate", "1");
        jsonParam.put("volume", "1");
        jsonParam.put("srtFlag", "1");
        jsonParam.put("matting", "1");
//        jsonParam.put("pixFmt", "yuv444p");
//        jsonParam.put("videoFormat", "100");

//        style	 控制模特大小及位置(具体位置说明参考第四章位置说明, 注意：目前该功能只支持输出mp4格式视频)
        JSONObject style = new JSONObject();
        style.put("x", "1");
        style.put("y", "1");
        style.put("width", "500");
        style.put("height", "500");
        style.put("indexLayer", "100");
        jsonParam.put("style", style);

//        nodes	array 在画面中添加素材(注意：目前该功能只支持输出mp4格式视频)
        JSONArray nodes = new JSONArray();

        JSONObject nodeStyleJSON = new JSONObject();
        nodeStyleJSON.put("type", "2");
        nodeStyleJSON.put("url", "https://cdn.guiji.ai/video-server/jpg/1816079643308826626.jpg");
        nodeStyleJSON.put("indexLayer", "50");
        nodeStyleJSON.put("rotation", "50");
        JSONObject json3 = new JSONObject();
        json3.put("x", "3");
        json3.put("y", "3");
        json3.put("width", "300");
        json3.put("height", "400");
        nodeStyleJSON.put("style", json3);
        nodes.add(nodeStyleJSON);

        JSONObject nodeJSON2 = new JSONObject();
        nodeJSON2.put("type", "1");
        nodeJSON2.put("url", "http://47.121.123.230:9000/xy-dev/comfyui/video/zhanghongrun.mp4");
        nodeJSON2.put("rotation", "101");
        JSONObject json4 = new JSONObject();
        json4.put("x", "4");
        json4.put("y", "4");
        json4.put("width", "50");
        json4.put("height", "50");
        nodeJSON2.put("style", json4);
        nodes.add(nodeJSON2);

        jsonParam.put("nodes", nodes);

        // srtStyle	 字幕样式（srtFlag=1生效）
        JSONObject srtStyle = new JSONObject();
        srtStyle.put("x", "300");
        srtStyle.put("y", "300");
        srtStyle.put("fontSize", "100");
        srtStyle.put("color", "#000000");
        srtStyle.put("width", "10");
        srtStyle.put("height", "10");

        jsonParam.put("srtStyle", srtStyle);

        log.info("创建合成视频任务-文本合成 推送参数jsonParam:" + jsonParam);
        //构造实体对象
        HttpEntity<JSONObject> param = new HttpEntity<>(jsonParam, headers);

        JSONObject returnDataJSON = restTemplate.postForObject(url, param, JSONObject.class);
        log.info("3.7 创建合成视频任务-文本合成:"+returnDataJSON.toJSONString());
        if ("0".equals(returnDataJSON.getString("code"))) {
            JSONObject dataJSON = returnDataJSON.getJSONObject("data");
            System.out.println(dataJSON);
            ArrayList records = dataJSON.getObject("records", ArrayList.class);
            for (int i = 0; i < records.size(); i++) {
                LinkedHashMap map = (LinkedHashMap)records.get(i);
                Object id = map.get("id");
                Object robotName = map.get("robotName");
                Object robotDesc = map.get("robotDesc");
                Object coverUrl = map.get("coverUrl");

            }
        }

    }
}
